@@ -3,6 +3,6 @@ library( RUnit )
 
 
 path <- system.file( "unittests", package="rjson" )
-path <- "."
+#path <- "."
 test.suite <- defineTestSuite( "json unittests", dirs = path, testFileRegexp = "^test\\..*\\.[rR]$" )
 runTestSuite( test.suite, verbose = 100 )
